@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Time;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.787';
+our $VERSION = '0.788';
 
 __PACKAGE__->add_common_method_maker_argument_names('default', 'scale', 'end_of_month_mode');
 
@@ -31,7 +31,7 @@ sub should_inline_value
 {
   my($self, $db, $value) = @_;
   no warnings 'uninitialized';
-  return (($db->validate_interval_keyword($value) && $db->should_inline_interval_keywords) ||
+  return (($db->validate_interval_keyword($value) && $db->should_inline_interval_keyword($value)) ||
           ($db->keyword_function_calls && $value =~ /^\w+\(.*\)$/)) ? 1 : 0;
 }
 
